DtoDesignPattern class

Inheritance

Constructors

DtoDesignPattern()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

extension() → String
override
generate() → bool
override
nameClass() → String
override
nameDesignPattern() → String
override
nameFile() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
path() → String
override
persistValue(String key, dynamic value) → dynamic
inherited
readTemplete(String group, String file, String template, String path) → String
inherited
template() → String
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited